@@ -352,7 +352,10 @@ def make_injection(signal, f_src, amplitude, src_pos, name, detector="H", delay=
     # dot(speed earth vector, Position source)
 
     #compute spped vector array (line: speed(x, y ,z),column: nb time step)
+    tm1 = time.perf_counter()
     speed_array = speed_vector_parallel(t1,t2,f_sampling)
+    print("speed_vector_parallel:  ",time.perf_counter() - tm1," second(s)")
+
 
     #compute cartesian coordinate from RA DEC.
     co = SkyCoord(ra= src_pos[0]*u.degree, dec=src_pos[1]*u.degree, frame='icrs')
@@ -370,6 +373,7 @@ def make_injection(signal, f_src, amplitude, src_pos, name, detector="H", delay=
 
     #send the empty array in the device
     d_signal = cuda.to_device(loc_signal)
+    d_freq = cuda.to_device(f_obs)
 
 
     # Set the number of threads in a block
@@ -384,7 +388,7 @@ def make_injection(signal, f_src, amplitude, src_pos, name, detector="H", delay=
 
     #Lunch the kernel
     t1 = time.perf_counter()
-    inject_signal[blockspergrid, threadsperblock](d_signal, t_0, f_obs, f_sampling,amplitude,phase)
+    inject_signal[blockspergrid, threadsperblock](d_signal, t_0, d_freq, f_sampling, amplitude, phase)
 
     #bring bah the data on the host
     signal_result=d_signal.copy_to_host()
